@@ -101,7 +101,9 @@ sub _list {
 		print $DB::OUT $file eq $run_file  &&  $line == $run_line ? '>>' : '  ';
 
 		print $DB::OUT DB::can_break( $file, $line ) ? 'x' : ' ';
-		print $DB::OUT "$line: " . ((my $tmp=$source->[ $line ]) =~ s/\t/    /g ); #/
+		(my $tmp =  $source->[ $line ]) =~ s/\t/    /g; #/
+		$tmp =  " $tmp"   if length $tmp > 1; # $tmp have at least "\n"
+		print $DB::OUT "$line:$tmp";
 	}
 }
 
@@ -344,7 +346,8 @@ $DB::commands =  {
 		$curr_file   =  DB::state( 'file' );
 		$line_cursor =  DB::state( 'line' );
 
-		print $DB::OUT "$curr_file:$line_cursor    " .((my $tmp=DB::source()->[ $line_cursor ]) =~ s/^(\s+)//); #/
+		(my $tmp=DB::source()->[ $line_cursor ]) =~ s/^\s+//;
+		print $DB::OUT "$curr_file:$line_cursor    $tmp";
 
 		1;
 	},
